Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEnvBool ¶
func GetEnvBool(config Configurator, field string) bool
GetEnvBool gets a bool from the environment, falling back to the same field name in the config struct. If it doesn't exist in either, the function will log an error and panic
func GetEnvFloat ¶ added in v0.3.0
func GetEnvFloat(config Configurator, field string) float64
GetEnvFloat gets a float from the environment, falling back to the same field name in the config struct. If it doesn't exist in either, the function will log an error and panic
func GetEnvInt ¶
func GetEnvInt(config Configurator, field string) int
GetEnvInt gets an int from the environment, falling back to the same field name in the config struct. If it doesn't exist in either, the function will log an error and panic
func GetEnvString ¶
func GetEnvString(config Configurator, field string) string
GetEnvString gets a string from the environment, falling back to the same field name in the config struct. If it doesn't exist in either, the function will log an error and panic